==> Spire.Xls-13.9.0-py3-none-win_amd64.whl: spire/xls/XlsStylesCollection.py <==
from enum import Enum
from plum import dispatch
from typing import TypeVar,Union,Generic,List,Tuple
from spire.xls.common import *
from spire.xls import *
from ctypes import *
import abc

class XlsStylesCollection (  CollectionBase[CellStyleObject], IStyles) :
    """

    """

    def Contains(self ,name:str)->bool:
        """
    <summary>
        Check collection contains style with specified name.
    </summary>
    <param name="name">Style name</param>
    <returns></returns>
        """
        
        GetDllLibXls().XlsStylesCollection_Contains.argtypes=[c_void_p ,c_void_p]
        GetDllLibXls().XlsStylesCollection_Contains.restype=c_bool
        ret = GetDllLibXls().XlsStylesCollection_Contains(self.Ptr, name)
        return ret


    def Remove(self ,styleName:str):
        """
    <summary>
        Removes style from the colleciton.
    </summary>
    <param name="styleName">Style to remove.</param>
        """
        
        GetDllLibXls().XlsStylesCollection_Remove.argtypes=[c_void_p ,c_void_p]
        GetDllLibXls().XlsStylesCollection_Remove(self.Ptr, styleName)


    def get_Item(self ,name:str)->'IStyle':
        """

        """
        
        GetDllLibXls().XlsStylesCollection_get_Item.argtypes=[c_void_p ,c_void_p]
        GetDllLibXls().XlsStylesCollection_get_Item.restype=c_void_p
        intPtr = GetDllLibXls().XlsStylesCollection_get_Item(self.Ptr, name)
        ret = None if intPtr==None else CellStyle(intPtr)
        return ret



    def Clone(self ,parent:'SpireObject')->'SpireObject':
        """

        """
        intPtrparent:c_void_p = parent.Ptr

        GetDllLibXls().XlsStylesCollection_Clone.argtypes=[c_void_p ,c_void_p]
        GetDllLibXls().XlsStylesCollection_Clone.restype=c_void_p
        intPtr = GetDllLibXls().XlsStylesCollection_Clone(self.Ptr, intPtrparent)
        ret = None if intPtr==None else SpireObject(intPtr)
        return ret


    def UpdateStyleRecords(self):
        """

        """
        GetDllLibXls().XlsStylesCollection_UpdateStyleRecords.argtypes=[c_void_p]
        GetDllLibXls().XlsStylesCollection_UpdateStyleRecords(self.Ptr)

==> Spire.Xls-14.4.4-py3-none-win_amd64.whl: spire/xls/XlsStylesCollection.py <==
from enum import Enum
from plum import dispatch
from typing import TypeVar,Union,Generic,List,Tuple
from spire.xls.common import *
from spire.xls import *
from ctypes import *
import abc

class XlsStylesCollection (  CollectionBase[CellStyleObject], IStyles) :
    """

    """

    def Contains(self ,name:str)->bool:
        """
    <summary>
        Check collection contains style with specified name.
    </summary>
    <param name="name">Style name</param>
    <returns></returns>
        """
        
        GetDllLibXls().XlsStylesCollection_Contains.argtypes=[c_void_p ,c_void_p]
        GetDllLibXls().XlsStylesCollection_Contains.restype=c_bool
        ret = CallCFunction(GetDllLibXls().XlsStylesCollection_Contains, self.Ptr, name)
        return ret


    def Remove(self ,styleName:str):
        """
    <summary>
        Removes style from the colleciton.
    </summary>
    <param name="styleName">Style to remove.</param>
        """
        
        GetDllLibXls().XlsStylesCollection_Remove.argtypes=[c_void_p ,c_void_p]
        CallCFunction(GetDllLibXls().XlsStylesCollection_Remove, self.Ptr, styleName)


    def get_Item(self ,name:str)->'IStyle':
        """

        """
        
        GetDllLibXls().XlsStylesCollection_get_Item.argtypes=[c_void_p ,c_void_p]
        GetDllLibXls().XlsStylesCollection_get_Item.restype=c_void_p
        intPtr = CallCFunction(GetDllLibXls().XlsStylesCollection_get_Item, self.Ptr, name)
        ret = None if intPtr==None else CellStyle(intPtr)
        return ret



    def Clone(self ,parent:'SpireObject')->'SpireObject':
        """

        """
        intPtrparent:c_void_p = parent.Ptr

        GetDllLibXls().XlsStylesCollection_Clone.argtypes=[c_void_p ,c_void_p]
        GetDllLibXls().XlsStylesCollection_Clone.restype=c_void_p
        intPtr = CallCFunction(GetDllLibXls().XlsStylesCollection_Clone, self.Ptr, intPtrparent)
        ret = None if intPtr==None else SpireObject(intPtr)
        return ret


    def UpdateStyleRecords(self):
        """

        """
        GetDllLibXls().XlsStylesCollection_UpdateStyleRecords.argtypes=[c_void_p]
        CallCFunction(GetDllLibXls().XlsStylesCollection_UpdateStyleRecords, self.Ptr)
